@@ -6,7 +6,7 @@ class ALBListenerHTTPS(BaseResourceCheck):
 
     def __init__(self):
         name = "Ensure ALB protocol is HTTPS"
-        id = "BC_AWS_ENCRYPTION_8"
+        id = "CKV_AWS_2"
         supported_resources = ['aws_alb_listener','aws_lb_listener']
         categories = [CheckCategories.ENCRYPTION]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
@@ -21,15 +21,15 @@ class ALBListenerHTTPS(BaseResourceCheck):
         key = 'protocol'
         if key in conf.keys():
             if conf[key] == ["HTTPS"]:
-                return CheckResult.SUCCESS
+                return CheckResult.PASSED
             elif conf[key] == ["HTTP"]:
                 if 'default_action' in conf.keys():
                     default_action = conf['default_action'][0]
                     action_type = default_action['type']
                     if action_type == ['redirect']:
                         if default_action['redirect'][0]['protocol'] == ['HTTPS']:
-                            return CheckResult.SUCCESS
-        return CheckResult.FAILURE
+                            return CheckResult.PASSED
+        return CheckResult.FAILED
 
 
 check = ALBListenerHTTPS()
