@@ -5,7 +5,7 @@ from checkov.terraform.checks.resource.base_check import BaseResourceCheck
 class ElasticsearchEncryption(BaseResourceCheck):
     def __init__(self):
         name = "Ensure all data stored in the Elasticsearch is securely encrypted at rest"
-        id = "BC_AWS_ES_1"
+        id = "CKV_AWS_5"
         supported_resources = ['aws_elasticsearch_domain']
         categories = [CheckCategories.ENCRYPTION]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
@@ -19,8 +19,8 @@ class ElasticsearchEncryption(BaseResourceCheck):
         """
         if "encrypt_at_rest" in conf.keys():
             if conf["encrypt_at_rest"][0]["enabled"][0]:
-                return CheckResult.SUCCESS
-        return CheckResult.FAILURE
+                return CheckResult.PASSED
+        return CheckResult.FAILED
 
 
 check = ElasticsearchEncryption()
