@@ -5,7 +5,7 @@ from checkov.terraform.checks.resource.base_check import BaseResourceCheck
 class PasswordPolicyLength(BaseResourceCheck):
     def __init__(self):
         name = "Ensure IAM password policy requires minimum length of 14 or greater"
-        id = "BC_AWS_IAM_9"
+        id = "CKV_AWS_10"
         supported_resources = ['aws_iam_account_password_policy']
         categories = [CheckCategories.IAM]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
@@ -19,9 +19,9 @@ class PasswordPolicyLength(BaseResourceCheck):
         """
         key = 'minimum_password_length'
         if key in conf.keys():
-            if conf[key] >= 14:
-                return CheckResult.SUCCESS
-        return CheckResult.FAILURE
+            if conf[key][0] >= 14:
+                return CheckResult.PASSED
+        return CheckResult.FAILED
 
 
 check = PasswordPolicyLength()
