@@ -5,7 +5,7 @@ from checkov.terraform.checks.resource.base_check import BaseResourceCheck
 class PasswordPolicyLowercaseLetter(BaseResourceCheck):
     def __init__(self):
         name = "Ensure IAM password policy requires at least one lowercase letter"
-        id = "BC_AWS_IAM_8"
+        id = "CKV_AWS_11"
         supported_resources = ['aws_iam_account_password_policy']
         categories = [CheckCategories.IAM]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
@@ -19,9 +19,9 @@ class PasswordPolicyLowercaseLetter(BaseResourceCheck):
         """
         key = 'require_lowercase_characters'
         if key in conf.keys():
-            if conf[key]:
-                return CheckResult.SUCCESS
-        return CheckResult.FAILURE
+            if conf[key][0]:
+                return CheckResult.PASSED
+        return CheckResult.FAILED
 
 
 check = PasswordPolicyLowercaseLetter()
