@@ -5,7 +5,7 @@ from checkov.terraform.checks.resource.base_check import BaseResourceCheck
 class RDSPubliclyAccessible(BaseResourceCheck):
     def __init__(self):
         name = "Ensure all data stored in the RDS bucket is not public accessible"
-        id = "BC_AWS_RDS_2"
+        id = "CKV_AWS_17"
         supported_resources = ['aws_db_instance','aws_rds_cluster_instance']
         categories = [CheckCategories.NETWORKING]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
@@ -20,8 +20,8 @@ class RDSPubliclyAccessible(BaseResourceCheck):
         if 'publicly_accessible' in conf.keys():
             key = conf['publicly_accessible'][0]
             if key:
-                return CheckResult.FAILURE
-        return CheckResult.SUCCESS
+                return CheckResult.FAILED
+        return CheckResult.PASSED
 
 
 check = RDSPubliclyAccessible()
