@@ -5,7 +5,7 @@ from checkov.terraform.checks.resource.base_check import BaseResourceCheck
 class S3PublicACL(BaseResourceCheck):
     def __init__(self):
         name = "S3 Bucket has an ACL defined which allows public access."
-        id = "BC_AWS_S3_1"
+        id = "CKV_AWS_20"
         supported_resources = ['aws_s3_bucket']
         categories = [CheckCategories.GENERAL_SECURITY]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
@@ -20,8 +20,8 @@ class S3PublicACL(BaseResourceCheck):
         if 'acl' in conf.keys():
             acl_block = conf['acl']
             if acl_block in [["public-read"],["public-read-write"],["website"]]:
-                return CheckResult.FAILURE
-        return CheckResult.SUCCESS
+                return CheckResult.FAILED
+        return CheckResult.PASSED
 
 
 check = S3PublicACL()
