@@ -7,7 +7,7 @@ PORT = 22
 class SecurityGroupUnrestrictedIngress22(BaseResourceCheck):
     def __init__(self):
         name = "Ensure no security groups allow ingress from 0.0.0.0:0 to port %d" % PORT
-        id = "BC_AWS_NETWORKING_1"
+        id = "CKV_AWS_24"
         supported_resources = ['aws_security_group']
         categories = [CheckCategories.NETWORKING]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
@@ -22,11 +22,12 @@ class SecurityGroupUnrestrictedIngress22(BaseResourceCheck):
         if 'ingress' in conf.keys():
             ingress_conf = conf['ingress']
             for rule in ingress_conf:
-                if rule['from_port'] == [PORT] and rule['to_port'] == [PORT] and rule['cidr_blocks'] == [[
-                    "0.0.0.0/0"]] and 'self' not in rule.keys() and 'security_groups' not in rule.keys():
-                    return CheckResult.FAILURE
+                if rule['from_port'] == [PORT] and rule['to_port'] == [PORT]:
+                    if 'cidr_blocks' in rule.keys():
+                        if rule['cidr_blocks'] == [["0.0.0.0/0"]] and 'security_groups' not in rule.keys():
+                            return CheckResult.FAILED
 
-        return CheckResult.SUCCESS
+        return CheckResult.PASSED
 
 
 check = SecurityGroupUnrestrictedIngress22()
