@@ -5,7 +5,7 @@ from checkov.terraform.checks.resource.base_check import BaseResourceCheck
 class GoogleStorageBucketEncryption(BaseResourceCheck):
     def __init__(self):
         name = "Ensure Google storage bucket have encryption enabled"
-        id = "BC_GCP_BUCKET_1"
+        id = "CKV_GCP_5"
         supported_resources = ['google_storage_bucket']
         categories = [CheckCategories.ENCRYPTION]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
@@ -22,8 +22,8 @@ class GoogleStorageBucketEncryption(BaseResourceCheck):
                 encryption_conf = conf['encryption'][0]
                 if 'default_kms_key_name'  in encryption_conf.keys():
                     if encryption_conf['default_kms_key_name']:
-                        return CheckResult.SUCCESS
-        return CheckResult.FAILURE
+                        return CheckResult.PASSED
+        return CheckResult.FAILED
 
 
 check = GoogleStorageBucketEncryption()
